You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@roller.apache.org by sn...@apache.org on 2011/04/02 23:52:51 UTC

svn commit: r1088146 - in /roller/trunk: weblogger-business/src/main/java/org/apache/roller/weblogger/planet/business/jpa/ weblogger-docs/installguide/ weblogger-docs/installguide/generated/ weblogger-docs/installguide/generated/html/

Author: snoopdave
Date: Sat Apr  2 21:52:50 2011
New Revision: 1088146

URL: http://svn.apache.org/viewvc?rev=1088146&view=rev
Log:
Issue ROL-1916: Verify Planet works on Glassfish and prominently point out planet-custom.properties 
https://issues.apache.org/jira/browse/ROL-1916

- Corrected cache dir property name in Install Guide
- Made sure JPARollerPlanetPersistenceStrategy uses same logic as non-Roller one

Modified:
    roller/trunk/weblogger-business/src/main/java/org/apache/roller/weblogger/planet/business/jpa/JPARollerPlanetPersistenceStrategy.java
    roller/trunk/weblogger-docs/installguide/generated/html/roller-install-guide.html
    roller/trunk/weblogger-docs/installguide/generated/roller-install-guide.pdf
    roller/trunk/weblogger-docs/installguide/roller-install-guide.odt

Modified: roller/trunk/weblogger-business/src/main/java/org/apache/roller/weblogger/planet/business/jpa/JPARollerPlanetPersistenceStrategy.java
URL: http://svn.apache.org/viewvc/roller/trunk/weblogger-business/src/main/java/org/apache/roller/weblogger/planet/business/jpa/JPARollerPlanetPersistenceStrategy.java?rev=1088146&r1=1088145&r2=1088146&view=diff
==============================================================================
--- roller/trunk/weblogger-docs/installguide/generated/html/roller-install-guide.html (original)
+++ roller/trunk/weblogger-docs/installguide/generated/html/roller-install-guide.html Sat Apr  2 21:52:50 2011
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <!DOCTYPE html
   PUBLIC "-//W3C//DTD XHTML 1.1 plus MathML 2.0//EN" "http://www.w3.org/TR/MathML2/dtd/xhtml-math11-f.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml"><!--This file was converted to xhtml by OpenOffice.org - see http://xml.openoffice.org/odf2xhtml for more info.--><head profile="http://dublincore.org/documents/dcmi-terms/"><meta http-equiv="Content-Type" content="application/xhtml+xml; charset=utf-8"/><title xml:lang="en-US">- no title specified</title><meta name="DCTERMS.title" content="" xml:lang="en-US"/><meta name="DCTERMS.language" content="en-US" scheme="DCTERMS.RFC4646"/><meta name="DCTERMS.source" content="http://xml.openoffice.org/odf2xhtml"/><meta name="DCTERMS.issued" content="2007-07-06T11:18:20" scheme="DCTERMS.W3CDTF"/><meta name="DCTERMS.modified" content="2011-03-15T17:29:37" scheme="DCTERMS.W3CDTF"/><meta name="DCTERMS.provenance" content="" xml:lang="en-US"/><meta name="DCTERMS.subject" content=", OpenDS Directory Server Administration Framework" xml:lang="en-US"/><link rel="schema.DC" href="http://purl.org/dc/elements/1.1/" hreflang="en"/><link rel="schema.DCTER
 MS" href="http://purl.org/dc/terms/" hreflang="en"/><link rel="schema.DCTYPE" href="http://purl.org/dc/dcmitype/" hreflang="en"/><link rel="schema.DCAM" href="http://purl.org/dc/dcam/" hreflang="en"/><base href="."/><style type="text/css">
+<html xmlns="http://www.w3.org/1999/xhtml"><!--This file was converted to xhtml by OpenOffice.org - see http://xml.openoffice.org/odf2xhtml for more info.--><head profile="http://dublincore.org/documents/dcmi-terms/"><meta http-equiv="Content-Type" content="application/xhtml+xml; charset=utf-8"/><title xml:lang="en-US">- no title specified</title><meta name="DCTERMS.title" content="" xml:lang="en-US"/><meta name="DCTERMS.language" content="en-US" scheme="DCTERMS.RFC4646"/><meta name="DCTERMS.source" content="http://xml.openoffice.org/odf2xhtml"/><meta name="DCTERMS.issued" content="2007-07-06T11:18:20" scheme="DCTERMS.W3CDTF"/><meta name="DCTERMS.modified" content="2011-04-02T17:48:34" scheme="DCTERMS.W3CDTF"/><meta name="DCTERMS.provenance" content="" xml:lang="en-US"/><meta name="DCTERMS.subject" content=", OpenDS Directory Server Administration Framework" xml:lang="en-US"/><link rel="schema.DC" href="http://purl.org/dc/elements/1.1/" hreflang="en"/><link rel="schema.DCTER
 MS" href="http://purl.org/dc/terms/" hreflang="en"/><link rel="schema.DCTYPE" href="http://purl.org/dc/dcmitype/" hreflang="en"/><link rel="schema.DCAM" href="http://purl.org/dc/dcam/" hreflang="en"/><base href="."/><style type="text/css">
 	@page {  }
 	table { border-collapse:collapse; border-spacing:0; empty-cells:show }
 	td, th { vertical-align:top; font-size:12pt;}
@@ -43,76 +43,75 @@
 	.P14 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
 	.P15 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; font-style:italic; font-weight:bold; }
 	.P16 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; font-weight:bold; }
-	.P17_borderStart { border-left-style:none; border-right-style:none; border-top-style:none; font-size:12pt; font-style:oblique; font-weight:bold; padding:0in; text-align:left ! important; font-family:Helvetica; writing-mode:lr-tb;  border-bottom-style:none; }
-	.P17 { border-left-style:none; border-right-style:none; font-size:12pt; font-style:oblique; font-weight:bold; padding:0in; text-align:left ! important; font-family:Helvetica; writing-mode:lr-tb;  border-top-style:none; border-bottom-style:none; }
-	.P17_borderEnd { border-bottom-width:0.0879cm; border-bottom-style:solid; border-bottom-color:#000000; border-left-style:none; border-right-style:none; font-size:12pt; font-style:oblique; font-weight:bold; padding:0in; text-align:left ! important; font-family:Helvetica; writing-mode:lr-tb;  border-top-style:none;}
-	.P18 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; text-align:left ! important; }
-	.P19 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; margin-top:0in; margin-bottom:0.1965in; text-align:left ! important; }
-	.P20 { font-size:11pt; margin-bottom:0in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
-	.P21 { font-size:12pt; margin-bottom:0in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
+	.P17 { font-size:16pt; font-weight:bold; margin-bottom:0.0835in; margin-left:0in; margin-right:0in; margin-top:0.1665in; text-indent:0in; font-family:Helvetica; writing-mode:lr-tb; }
+	.P18_borderStart { border-left-style:none; border-right-style:none; border-top-style:none; font-size:12pt; font-style:oblique; font-weight:bold; padding:0in; text-align:left ! important; font-family:Helvetica; writing-mode:lr-tb;  border-bottom-style:none; }
+	.P18 { border-left-style:none; border-right-style:none; font-size:12pt; font-style:oblique; font-weight:bold; padding:0in; text-align:left ! important; font-family:Helvetica; writing-mode:lr-tb;  border-top-style:none; border-bottom-style:none; }
+	.P18_borderEnd { border-bottom-width:0.0879cm; border-bottom-style:solid; border-bottom-color:#000000; border-left-style:none; border-right-style:none; font-size:12pt; font-style:oblique; font-weight:bold; padding:0in; text-align:left ! important; font-family:Helvetica; writing-mode:lr-tb;  border-top-style:none;}
+	.P19 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; text-align:left ! important; }
+	.P20 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; margin-top:0in; margin-bottom:0.1965in; text-align:left ! important; }
+	.P21 { font-size:11pt; margin-bottom:0in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
 	.P22 { font-size:12pt; margin-bottom:0in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
-	.P23_borderStart { font-size:12pt; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-bottom:0in;  border-bottom-style:none; }
-	.P23 { font-size:12pt; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-bottom:0in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
-	.P23_borderEnd { font-size:12pt; margin-bottom:0in; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-top:0in;  border-top-style:none;}
-	.P24_borderStart { font-size:14pt; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-bottom:0in;  border-bottom-style:none; }
-	.P24 { font-size:14pt; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-bottom:0in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
-	.P24_borderEnd { font-size:14pt; margin-bottom:0in; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-top:0in;  border-top-style:none;}
-	.P25 { font-size:11pt; margin-bottom:0in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
-	.P26 { font-size:8pt; margin-bottom:0in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
-	.P27 { font-size:14pt; margin-bottom:0in; margin-top:0in; font-family:Cumberland; writing-mode:lr-tb; }
-	.P28 { font-size:14pt; margin-bottom:0in; margin-top:0in; font-family:Cumberland; writing-mode:lr-tb; font-style:italic; font-weight:bold; }
-	.P29 { font-size:10pt; margin-bottom:0in; margin-top:0in; font-family:Cumberland; writing-mode:lr-tb; }
+	.P23 { font-size:12pt; margin-bottom:0in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
+	.P24_borderStart { font-size:12pt; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-bottom:0in;  border-bottom-style:none; }
+	.P24 { font-size:12pt; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-bottom:0in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
+	.P24_borderEnd { font-size:12pt; margin-bottom:0in; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-top:0in;  border-top-style:none;}
+	.P25_borderStart { font-size:14pt; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-bottom:0in;  border-bottom-style:none; }
+	.P25 { font-size:14pt; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-bottom:0in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
+	.P25_borderEnd { font-size:14pt; margin-bottom:0in; font-family:Courier New; writing-mode:lr-tb; background-color:transparent; padding-top:0in;  border-top-style:none;}
+	.P26 { font-size:11pt; margin-bottom:0in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
+	.P27 { font-size:8pt; margin-bottom:0in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
+	.P28 { font-size:14pt; margin-bottom:0in; margin-top:0in; font-family:Cumberland; writing-mode:lr-tb; }
+	.P29 { font-size:14pt; margin-bottom:0in; margin-top:0in; font-family:Cumberland; writing-mode:lr-tb; font-style:italic; font-weight:bold; }
 	.P3 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; text-align:left ! important; background-color:transparent; }
-	.P30_borderStart { font-size:12pt; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-bottom:0.0835in;  border-bottom-style:none; }
-	.P30 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-bottom:0.0835in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
-	.P30_borderEnd { font-size:12pt; margin-bottom:0.0835in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-top:0in;  border-top-style:none;}
-	.P31 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; font-style:normal; }
-	.P32 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; font-style:normal; }
-	.P33 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
-	.P34 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
-	.P35 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; font-weight:bold; }
-	.P36 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; font-weight:normal; }
-	.P37 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P38 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; text-align:left ! important; }
-	.P39_borderStart { font-size:14pt; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; background-color:transparent; padding-bottom:0.0835in;  border-bottom-style:none; }
-	.P39 { font-size:14pt; font-family:Times New Roman; writing-mode:lr-tb; background-color:transparent; padding-bottom:0.0835in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
-	.P39_borderEnd { font-size:14pt; margin-bottom:0.0835in; font-family:Times New Roman; writing-mode:lr-tb; background-color:transparent; padding-top:0in;  border-top-style:none;}
+	.P30 { font-size:10pt; margin-bottom:0in; margin-top:0in; font-family:Cumberland; writing-mode:lr-tb; }
+	.P31_borderStart { font-size:12pt; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-bottom:0.0835in;  border-bottom-style:none; }
+	.P31 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-bottom:0.0835in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
+	.P31_borderEnd { font-size:12pt; margin-bottom:0.0835in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-top:0in;  border-top-style:none;}
+	.P32 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; font-style:normal; }
+	.P33 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; font-style:normal; }
+	.P34 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
+	.P35 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; }
+	.P36 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; font-weight:bold; }
+	.P37 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; font-weight:normal; }
+	.P38 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P39 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; text-align:left ! important; }
 	.P4 { font-size:16pt; font-family:Helvetica; writing-mode:lr-tb; text-align:left ! important; background-color:transparent; font-weight:bold; }
-	.P40_borderStart { font-size:14pt; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffffff; padding-bottom:0.0835in;  border-bottom-style:none; }
-	.P40 { font-size:14pt; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffffff; padding-bottom:0.0835in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
-	.P40_borderEnd { font-size:14pt; margin-bottom:0.0835in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffffff; padding-top:0in;  border-top-style:none;}
-	.P41 { font-size:11pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P42 { font-size:9pt; margin-bottom:0.0835in; margin-top:0in; font-family:Courier; writing-mode:lr-tb; color:#000000; }
-	.P43 { font-size:9pt; font-family:Courier; writing-mode:lr-tb; margin-left:0in; margin-right:0in; text-align:left ! important; text-indent:0in; color:#000000; }
-	.P44_borderStart { border-left-style:none; border-right-style:none; border-top-style:none; font-size:22pt; font-style:italic; font-weight:bold; margin-top:0.1665in; padding:0in; font-family:Helvetica; writing-mode:lr-tb; padding-bottom:0.0835in;  border-bottom-style:none; }
-	.P44 { border-left-style:none; border-right-style:none; font-size:22pt; font-style:italic; font-weight:bold; padding:0in; font-family:Helvetica; writing-mode:lr-tb; padding-bottom:0.0835in; padding-top:0.1665in;  border-top-style:none; border-bottom-style:none; }
-	.P44_borderEnd { border-bottom-width:0.0879cm; border-bottom-style:solid; border-bottom-color:#000000; border-left-style:none; border-right-style:none; font-size:22pt; font-style:italic; font-weight:bold; margin-bottom:0.0835in; padding:0in; font-family:Helvetica; writing-mode:lr-tb; padding-top:0.1665in;  border-top-style:none;}
-	.P45 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P46 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P47 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P48 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P49 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P40_borderStart { font-size:14pt; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; background-color:transparent; padding-bottom:0.0835in;  border-bottom-style:none; }
+	.P40 { font-size:14pt; font-family:Times New Roman; writing-mode:lr-tb; background-color:transparent; padding-bottom:0.0835in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
+	.P40_borderEnd { font-size:14pt; margin-bottom:0.0835in; font-family:Times New Roman; writing-mode:lr-tb; background-color:transparent; padding-top:0in;  border-top-style:none;}
+	.P41_borderStart { font-size:14pt; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffffff; padding-bottom:0.0835in;  border-bottom-style:none; }
+	.P41 { font-size:14pt; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffffff; padding-bottom:0.0835in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
+	.P41_borderEnd { font-size:14pt; margin-bottom:0.0835in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffffff; padding-top:0in;  border-top-style:none;}
+	.P42 { font-size:11pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P43 { font-size:9pt; margin-bottom:0.0835in; margin-top:0in; font-family:Courier; writing-mode:lr-tb; color:#000000; }
+	.P44 { font-size:9pt; font-family:Courier; writing-mode:lr-tb; margin-left:0in; margin-right:0in; text-align:left ! important; text-indent:0in; color:#000000; }
+	.P45 { font-size:12pt; margin-left:0.1965in; margin-right:0in; text-indent:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P46 { font-size:12pt; font-weight:bold; margin-left:0in; margin-right:0in; text-indent:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P47 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; text-align:right ! important; background-color:transparent; }
+	.P48_borderStart { border-left-style:none; border-right-style:none; border-top-style:none; font-size:22pt; font-style:italic; font-weight:bold; margin-top:0.1665in; padding:0in; font-family:Helvetica; writing-mode:lr-tb; padding-bottom:0.0835in;  border-bottom-style:none; }
+	.P48 { border-left-style:none; border-right-style:none; font-size:22pt; font-style:italic; font-weight:bold; padding:0in; font-family:Helvetica; writing-mode:lr-tb; padding-bottom:0.0835in; padding-top:0.1665in;  border-top-style:none; border-bottom-style:none; }
+	.P48_borderEnd { border-bottom-width:0.0879cm; border-bottom-style:solid; border-bottom-color:#000000; border-left-style:none; border-right-style:none; font-size:22pt; font-style:italic; font-weight:bold; margin-bottom:0.0835in; padding:0in; font-family:Helvetica; writing-mode:lr-tb; padding-top:0.1665in;  border-top-style:none;}
 	.P5 { font-size:13pt; font-family:Times New Roman; writing-mode:lr-tb; text-align:left ! important; background-color:transparent; }
 	.P50 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P51 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P52 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P53 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P54_borderStart { font-size:12pt; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-bottom:0.0835in;  border-bottom-style:none; }
-	.P54 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-bottom:0.0835in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
-	.P54_borderEnd { font-size:12pt; margin-bottom:0.0835in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-top:0in;  border-top-style:none;}
-	.P55 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P56 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; margin-left:1in; margin-right:0in; text-indent:0in; }
-	.P57 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; margin-left:0.5in; margin-right:0in; text-indent:0in; }
-	.P58 { font-size:18pt; font-style:italic; font-weight:bold; margin-bottom:0.0835in; margin-top:0.1665in; font-family:Helvetica; writing-mode:lr-tb; }
-	.P59 { font-size:18pt; font-style:italic; font-weight:bold; margin-bottom:0.0835in; margin-top:0.1665in; font-family:Helvetica; writing-mode:lr-tb; }
+	.P51 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P52 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P53 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P55 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P56 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P57 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P58 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P59_borderStart { font-size:12pt; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-bottom:0.0835in;  border-bottom-style:none; }
+	.P59 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-bottom:0.0835in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
+	.P59_borderEnd { font-size:12pt; margin-bottom:0.0835in; font-family:Times New Roman; writing-mode:lr-tb; background-color:#ffff00; padding-top:0in;  border-top-style:none;}
 	.P6_borderStart { font-size:13pt; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; text-align:left ! important; background-color:transparent; font-weight:normal; padding-bottom:0.0835in;  border-bottom-style:none; }
 	.P6 { font-size:13pt; font-family:Times New Roman; writing-mode:lr-tb; text-align:left ! important; background-color:transparent; font-weight:normal; padding-bottom:0.0835in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
 	.P6_borderEnd { font-size:13pt; margin-bottom:0.0835in; font-family:Times New Roman; writing-mode:lr-tb; text-align:left ! important; background-color:transparent; font-weight:normal; padding-top:0in;  border-top-style:none;}
-	.P60 { font-size:18pt; font-style:italic; font-weight:bold; margin-bottom:0.0835in; margin-top:0.1665in; font-family:Helvetica; writing-mode:lr-tb; }
-	.P61 { font-size:16pt; font-weight:bold; margin-bottom:0.0835in; margin-left:0in; margin-right:0in; margin-top:0.1665in; text-indent:0in; font-family:Helvetica; writing-mode:lr-tb; }
-	.P62 { font-size:12pt; margin-left:0.1965in; margin-right:0in; text-indent:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P63 { font-size:12pt; font-weight:bold; margin-left:0in; margin-right:0in; text-indent:0in; font-family:Times New Roman; writing-mode:lr-tb; }
-	.P64 { font-size:12pt; font-family:Times New Roman; writing-mode:lr-tb; text-align:right ! important; background-color:transparent; }
+	.P60 { font-size:12pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; }
+	.P61 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Courier New; writing-mode:lr-tb; margin-left:1in; margin-right:0in; text-indent:0in; }
+	.P62 { font-size:14pt; margin-bottom:0.0835in; margin-top:0in; font-family:Times New Roman; writing-mode:lr-tb; margin-left:0.5in; margin-right:0in; text-indent:0in; }
+	.P63 { font-size:18pt; font-style:italic; font-weight:bold; margin-bottom:0.0835in; margin-top:0.1665in; font-family:Helvetica; writing-mode:lr-tb; }
+	.P64 { font-size:18pt; font-style:italic; font-weight:bold; margin-bottom:0.0835in; margin-top:0.1665in; font-family:Helvetica; writing-mode:lr-tb; }
+	.P65 { font-size:18pt; font-style:italic; font-weight:bold; margin-bottom:0.0835in; margin-top:0.1665in; font-family:Helvetica; writing-mode:lr-tb; }
 	.P7_borderStart { font-size:36pt; margin-top:0in; font-family:Helvetica, sans-serif; writing-mode:lr-tb; text-align:right ! important; background-color:transparent; font-weight:bold; padding-bottom:0in;  border-bottom-style:none; }
 	.P7 { font-size:36pt; font-family:Helvetica, sans-serif; writing-mode:lr-tb; text-align:right ! important; background-color:transparent; font-weight:bold; padding-bottom:0in; padding-top:0in;  border-top-style:none; border-bottom-style:none; }
 	.P7_borderEnd { font-size:36pt; margin-bottom:0in; font-family:Helvetica, sans-serif; writing-mode:lr-tb; text-align:right ! important; background-color:transparent; font-weight:bold; padding-top:0in;  border-top-style:none;}
@@ -175,4 +174,4 @@
 	.Teletype { font-family:Cumberland, monospace; }
 	<!-- ODF styles with no properties representable as CSS -->
 	.Sect2 .Endnote_20_Symbol .Footnote_20_Symbol .Numbering_20_Symbols { }

[... 5 lines stripped ...]
Modified: roller/trunk/weblogger-docs/installguide/generated/roller-install-guide.pdf
URL: http://svn.apache.org/viewvc/roller/trunk/weblogger-docs/installguide/generated/roller-install-guide.pdf?rev=1088146&r1=1088145&r2=1088146&view=diff
==============================================================================
Binary files - no diff available.

Modified: roller/trunk/weblogger-docs/installguide/roller-install-guide.odt
URL: http://svn.apache.org/viewvc/roller/trunk/weblogger-docs/installguide/roller-install-guide.odt?rev=1088146&r1=1088145&r2=1088146&view=diff
==============================================================================
Binary files - no diff available.
--- roller/trunk/weblogger-business/src/main/java/org/apache/roller/weblogger/planet/business/jpa/JPARollerPlanetPersistenceStrategy.java (original)
+++ roller/trunk/weblogger-business/src/main/java/org/apache/roller/weblogger/planet/business/jpa/JPARollerPlanetPersistenceStrategy.java Sat Apr  2 21:52:50 2011
@@ -20,19 +20,25 @@ package org.apache.roller.weblogger.plan
 
 import java.util.Enumeration;
 import java.util.Properties;
+
+import javax.naming.InitialContext;
+import javax.naming.NamingException;
+import javax.persistence.EntityManagerFactory;
 import javax.persistence.Persistence;
 import javax.persistence.PersistenceException;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.roller.planet.PlanetException;
 import org.apache.roller.planet.business.jpa.JPAPersistenceStrategy;
+import org.apache.roller.planet.config.PlanetConfig;
 import org.apache.roller.weblogger.business.DatabaseProvider;
 import org.apache.roller.weblogger.business.startup.WebloggerStartup;
 import org.apache.roller.weblogger.config.WebloggerConfig;
 
 
 /**
  * JPA strategy for Planet, uses WebloggerConfig to get JPA configuration.
  */
 @com.google.inject.Singleton
 public class JPARollerPlanetPersistenceStrategy extends JPAPersistenceStrategy {
@@ -42,7 +48,7 @@ public class JPARollerPlanetPersistenceS
     
     
     /**
-     * Construct by finding using DatabaseProvider and WebloggerConfig.
+     * Uses database configuration information from WebloggerConfig (i.e. roller-custom.properties)
      * 
      * @throws org.apache.roller.PlanetException on any error
      */
@@ -50,42 +56,49 @@ public class JPARollerPlanetPersistenceS
 
         DatabaseProvider dbProvider = WebloggerStartup.getDatabaseProvider();
                         
-        // Add all OpenJPA and Toplinks properties found in WebloggerConfig
-        Properties emfProps = new Properties();
-        Enumeration keys = WebloggerConfig.keys();
-        while (keys.hasMoreElements()) {
-            String key = (String)keys.nextElement();
-            if (key.startsWith("openjpa.") || key.startsWith("toplink.")) {
-                String value = WebloggerConfig.getProperty(key);
-                logger.info(key + ": " + value);
-                emfProps.setProperty(key, value);
+        String jpaConfigurationType = PlanetConfig.getProperty("jpa.configurationType");
+        if ("jndi".equals(jpaConfigurationType)) {
+        	// If JNDI configuration type specified in Planet Config then use it
+            // Lookup EMF via JNDI: added for Geronimo
+            String emfJndiName = "java:comp/env/" + PlanetConfig.getProperty("jpa.emf.jndi.name");
+            try {
+                emf = (EntityManagerFactory) new InitialContext().lookup(emfJndiName);
+            } catch (NamingException e) {
+                throw new PlanetException("Could not look up EntityManagerFactory in jndi at " + emfJndiName, e);
             }
-        }
-        
-        if (dbProvider.getType() == DatabaseProvider.ConfigurationType.JNDI_NAME) {
-            // We're doing JNDI, so set OpenJPA JNDI name property
-            String jndiName = "java:comp/env/" + dbProvider.getJndiName();
-            emfProps.setProperty("openjpa.ConnectionFactoryName", jndiName);
             
         } else {
-            emfProps.setProperty("javax.persistence.jdbc.driver", dbProvider.getJdbcDriverClass());
-            emfProps.setProperty("javax.persistence.jdbc.url", dbProvider.getJdbcConnectionURL());
-            emfProps.setProperty("javax.persistence.jdbc.user", dbProvider.getJdbcUsername());
-            emfProps.setProperty("javax.persistence.jdbc.password", dbProvider.getJdbcPassword());
-
-            // And Hibernate JPA?
-            emfProps.setProperty("hibernate.connection.driver_class",dbProvider.getJdbcDriverClass());
-            emfProps.setProperty("hibernate.connection.url",         dbProvider.getJdbcConnectionURL());
-            emfProps.setProperty("hibernate.connection.username",    dbProvider.getJdbcUsername());
-            emfProps.setProperty("hibernate.connection.password",    dbProvider.getJdbcPassword()); 
-        }
-        
-        try {
-            emf = Persistence.createEntityManagerFactory("PlanetPU", emfProps);
-        } catch (PersistenceException pe) {
-            logger.error("ERROR: creating entity manager", pe);
-            throw new PlanetException(pe);
-        }
-    }
-    
+        	
+            // Add all JPA, OpenJPA, HibernateJPA, etc. properties found
+            Properties emfProps = new Properties();
+            Enumeration keys = WebloggerConfig.keys();
+            while (keys.hasMoreElements()) {
+                String key = (String) keys.nextElement();
+                if (       key.startsWith("javax.persistence.") 
+                        || key.startsWith("openjpa.") 
+                        || key.startsWith("hibernate.")) {
+                    String value = WebloggerConfig.getProperty(key);
+                    logger.info(key + ": " + value);
+                    emfProps.setProperty(key, value);
+                }
+            }
+	        
+            if (dbProvider.getType() == DatabaseProvider.ConfigurationType.JNDI_NAME) {
+                emfProps.setProperty("javax.persistence.nonJtaDataSource", dbProvider.getJndiName());
+
+            } else {
+                emfProps.setProperty("javax.persistence.jdbc.driver", dbProvider.getJdbcDriverClass());
+                emfProps.setProperty("javax.persistence.jdbc.url", dbProvider.getJdbcConnectionURL());
+                emfProps.setProperty("javax.persistence.jdbc.user", dbProvider.getJdbcUsername());
+                emfProps.setProperty("javax.persistence.jdbc.password", dbProvider.getJdbcPassword());
+            }
+            
+            try {
+                emf = Persistence.createEntityManagerFactory("PlanetPU", emfProps);
+            } catch (PersistenceException pe) {
+                logger.error("ERROR: creating entity manager", pe);
+                throw new PlanetException(pe);
+            }
+        }        
+    }  
 }
@@ -20,19 +20,25 @@ package org.apache.roller.weblogger.plan
 
 /**
- * JPA strategy for Planet, uses WebloggerConfig to get JPA configuration.
+ * JPA strategy for Planet, uses PlanetConfig to get JPA configuration.
  */
 @com.google.inject.Singleton

Modified: roller/trunk/weblogger-docs/installguide/generated/html/roller-install-guide.html
URL: http://svn.apache.org/viewvc/roller/trunk/weblogger-docs/installguide/generated/html/roller-install-guide.html?rev=1088146&r1=1088145&r2=1088146&view=diff
==============================================================================